# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from helix_platform_api_public_client.models.nomination_gates_overview_response import NominationGatesOverviewResponse  # noqa: E501

class TestNominationGatesOverviewResponse(unittest.TestCase):
    """NominationGatesOverviewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NominationGatesOverviewResponse:
        """Test NominationGatesOverviewResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NominationGatesOverviewResponse`
        """
        model = NominationGatesOverviewResponse()  # noqa: E501
        if include_optional:
            return NominationGatesOverviewResponse(
                long_term = helix_platform_api_public_client.models.nomination_gates_overview_response_long_term.NominationGatesOverviewResponse_longTerm(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                day_ahead = helix_platform_api_public_client.models.nomination_gates_overview_response_day_ahead.NominationGatesOverviewResponse_dayAhead(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                intra_day = [
                    helix_platform_api_public_client.models.nomination_gates_overview_response_intra_day.NominationGatesOverviewResponse_intraDay(
                        gate = helix_platform_api_public_client.models.intra_day_nomination_gate.IntraDayNominationGate(
                            id = 'bf325375-e030-fccb-a009-17317c574773:0762-06-86', 
                            product_type = 'ID_01', 
                            name = '', 
                            delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                            mtu_period = helix_platform_api_public_client.models.local_mtu_period.LocalMtuPeriod(
                                from_mtu_start = '10:00', 
                                to_mtu_end = '18:00', ), 
                            status = 'OPEN', ), 
                        next_action_at = '2022-01-04T00:00Z', )
                    ]
            )
        else:
            return NominationGatesOverviewResponse(
                long_term = helix_platform_api_public_client.models.nomination_gates_overview_response_long_term.NominationGatesOverviewResponse_longTerm(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                day_ahead = helix_platform_api_public_client.models.nomination_gates_overview_response_day_ahead.NominationGatesOverviewResponse_dayAhead(
                    gate = helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate.LongTermOrDayAheadNominationGate(
                        delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                        timescale = 'LONG_TERM', 
                        status = 'OPEN', ), 
                    next_action_at = '2022-01-04T00:00Z', ),
                intra_day = [
                    helix_platform_api_public_client.models.nomination_gates_overview_response_intra_day.NominationGatesOverviewResponse_intraDay(
                        gate = helix_platform_api_public_client.models.intra_day_nomination_gate.IntraDayNominationGate(
                            id = 'bf325375-e030-fccb-a009-17317c574773:0762-06-86', 
                            product_type = 'ID_01', 
                            name = '', 
                            delivery_day = 'Tue Jan 04 00:00:00 UTC 2022', 
                            mtu_period = helix_platform_api_public_client.models.local_mtu_period.LocalMtuPeriod(
                                from_mtu_start = '10:00', 
                                to_mtu_end = '18:00', ), 
                            status = 'OPEN', ), 
                        next_action_at = '2022-01-04T00:00Z', )
                    ],
        )
        """

    def testNominationGatesOverviewResponse(self):
        """Test NominationGatesOverviewResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
