# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date

from pydantic import BaseModel, Field, StrictStr, constr, validator
from helix_platform_api_public_client.models.intra_day_product_type import IntraDayProductType
from helix_platform_api_public_client.models.local_mtu_period import LocalMtuPeriod
from helix_platform_api_public_client.models.nomination_gate_status import NominationGateStatus

class IntraDayNominationGate(BaseModel):
    """
    IntraDayNominationGate
    """
    id: constr(strict=True) = Field(..., description="Virtual ID of a \"Workflow\" in the following format `{recurringWorkflowId}:{executionDay}`  Example: `684df173-4110-4e0d-b364-d2364388afe3:2024-06-01` ")
    product_type: IntraDayProductType = Field(..., alias="productType")
    name: StrictStr = Field(...)
    delivery_day: date = Field(..., alias="deliveryDay", description="One single calendar day, interpreted in **System Time**  - ISO 8601 compliant string in `yyyy-mm-dd` format ")
    mtu_period: LocalMtuPeriod = Field(..., alias="mtuPeriod")
    status: NominationGateStatus = Field(...)
    __properties = ["id", "productType", "name", "deliveryDay", "mtuPeriod", "status"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of mtu_period
        if self.mtu_period:
            _dict['mtuPeriod'] = self.mtu_period.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> IntraDayNominationGate:
        """Create an instance of IntraDayNominationGate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return IntraDayNominationGate.parse_obj(obj)

        _obj = IntraDayNominationGate.parse_obj({
            "id": obj.get("id"),
            "product_type": obj.get("productType"),
            "name": obj.get("name"),
            "delivery_day": obj.get("deliveryDay"),
            "mtu_period": LocalMtuPeriod.from_dict(obj.get("mtuPeriod")) if obj.get("mtuPeriod") is not None else None,
            "status": obj.get("status")
        })
        return _obj


