# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class UserRole(str, Enum):
    """
    UserRole
    """

    """
    allowed enum values
    """
    ICO_ADMIN = 'ICO_ADMIN'
    ICO_CURTAILMENT_MANAGER = 'ICO_CURTAILMENT_MANAGER'
    ICO_VIEW = 'ICO_VIEW'
    PART_ADMIN = 'PART_ADMIN'
    PART_NOMINATOR = 'PART_NOMINATOR'
    PART_VIEW = 'PART_VIEW'

    @classmethod
    def from_json(cls, json_str: str) -> UserRole:
        """Create an instance of UserRole from a JSON string"""
        return UserRole(json.loads(json_str))


