# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Helix**, the nomination platform of ElecLink_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/eleclink-helix/platform-api) 

    The version of the OpenAPI document: 0.0.116
    Contact: team.eleclink@eleclink.co.uk
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field
from helix_platform_api_public_client.models.long_term_or_day_ahead_nomination_gate import LongTermOrDayAheadNominationGate

class NominationGatesOverviewResponseDayAhead(BaseModel):
    """
    NominationGatesOverviewResponseDayAhead
    """
    gate: LongTermOrDayAheadNominationGate = Field(...)
    next_action_at: Optional[datetime] = Field(None, alias="nextActionAt", description="Date and time with zone information, marks an **absolute point** on the timeline  - theoretically can be sent and received with any zone offset (until it marks the desired **absolute point** on the timeline) - in practice it is advised to transfer it in UTC timezone (with Z offset, \"Zulu time\") - ISO 8601 compliant string in `yyyy-mm-ddThh:mm:ss.SSSZ` format ")
    __properties = ["gate", "nextActionAt"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> NominationGatesOverviewResponseDayAhead:
        """Create an instance of NominationGatesOverviewResponseDayAhead from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of gate
        if self.gate:
            _dict['gate'] = self.gate.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> NominationGatesOverviewResponseDayAhead:
        """Create an instance of NominationGatesOverviewResponseDayAhead from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return NominationGatesOverviewResponseDayAhead.parse_obj(obj)

        _obj = NominationGatesOverviewResponseDayAhead.parse_obj({
            "gate": LongTermOrDayAheadNominationGate.from_dict(obj.get("gate")) if obj.get("gate") is not None else None,
            "next_action_at": obj.get("nextActionAt")
        })
        return _obj


